@@ -2,7 +2,7 @@ import numpy as np
 
 from .. import specialhopping
 
-def get_hamiltonian(self,tij=None,fun=None,has_spin=True,ts=None,
+def get_hamiltonian(self,tij=None,has_spin=True,
                         is_sparse=False,spinful_generator=False,nc=2,
                         is_multicell=False,mgenerator=None,**kwargs):
     """ Create the hamiltonian for this geometry. By default, it assumes
@@ -13,19 +13,17 @@ def get_hamiltonian(self,tij=None,fun=None,has_spin=True,ts=None,
         - tij = None, function that return the spatially dependent hoppings
     """
     ### Perform some initial sanity checks
-    if fun is not None: 
-        print("fun will be deprecated, use instead tij")
-        tij = fun # overwrite
     ## in case tij is an iterable with hoppings
     from ..checkclass import is_iterable
     if is_iterable(tij): # tij is an iterable
-        ts = tij # overwrite
-        tij = None
-    #####
-    if ts is not None: # if hoppings given, overwrite mgenerator
+        ts = tij # overwrite the 1st, 2nd etc hoppings
         mgenerator = specialhopping.neighbor_hopping_matrix(self,ts)
         is_multicell = True # overwrite
         nc = 2*len(ts) + 1 # overwrite
+        tij = None # set tij to None
+    if type(tij)==specialhopping.HoppingGenerator: # for hopping generator
+        mgenerator = tij.f # store the function
+        tij = None # and set to None
     if self.dimensionality==3: is_multicell=True
     from ..hamiltonians import Hamiltonian
     h = Hamiltonian(self)  # create the object
@@ -34,7 +32,7 @@ def get_hamiltonian(self,tij=None,fun=None,has_spin=True,ts=None,
     h.is_multicell = is_multicell
     if is_multicell:  # workaround for multicell hamiltonians
       from ..multicell import parametric_hopping_hamiltonian
-      if mgenerator is not None:
+      if mgenerator is not None: # if mgenerator is given
           from ..multicell import parametric_matrix # not implemented
           h = parametric_matrix(h,fm=mgenerator,cutoff=nc,**kwargs)
       else: h = parametric_hopping_hamiltonian(h,fc=tij,**kwargs) # add hopping
